<?php
/*********************************************************************************
** The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 *
 ********************************************************************************/
/**
 * this file can be used to internationalise the strings present in the picklist
 */
$mod_strings = array(
	'LBL_ASSIGN_BUTTON'=>'Asignar',
	'ADD_PICKLIST_VALUES'=>'Añadir valores de selección',
	'LBL_EXISTING_PICKLIST_VALUES'=>'Valores de selección actuales',
	'LBL_PICKLIST_ADDINFO'=>'Añade nuevos valores a continuación',
	'LBL_SELECT_ROLES'=>'Selecciona roles',
	'LBL_NON_EDITABLE_PICKLIST_ENTRIES'=>'Valores No-editables',
	'EDIT_PICKLIST_VALUE'=>'Edita valores selección',
	'LBL_EDIT_HERE'=>'Sustituir con: ',
	'LBL_SELECT_TO_EDIT'=>'Selecciona un valor para editar: ',
	'DELETE_PICKLIST_VALUES'=>'Elimina valores de selección',
	'LBL_REPLACE_WITH'=>'Reemplazar con: ',
	'ASSIGN_PICKLIST_VALUES'=>'Asigna valores de selección',
	'LBL_PICKLIST_VALUES'=>'Valores de selección disponibles',
	'LBL_PICKLIST_VALUES_ASSIGNED_TO'=>'Asigna valores de selección para ',
	'LBL_ADD_TO_OTHER_ROLES'=>'Añade a otros roles',
	'LBL_OK_BUTTON_LABEL'=>'Vale',
	'LBL_SELECT_ROLES'=>'Selecciona roles',
	'LBL_DISPLAYED_VALUES'=>'Los valores accesibles por el rol están abajo',

	// For Dependency picklist
	'LBL_PICKLIST_DEPENDENCY_SETUP' => 'Configuración Dependencias entre Listas',
	'LBL_PICKLIST_DEPENDENCY_DESCRIPTION' => 'Establece Dependencias entre los elementos de las listas desplegables en cada módulo',
	'LBL_NEW_DEPENDENCY' => 'Nueva Dependencia entre Listas',
	'LBL_TOOLS' => 'Herramientas',
	'LBL_SOURCE_FIELD' => 'Campo Origen',
	'LBL_TARGET_FIELD' => 'Campo Destino',
	'LBL_BUTTON_SELECTED_SOURCE_VALUES' => 'Selecciona Valores Origen',
	'LBL_SELECTED_SOURCE_VALUES_MSG' => 'Selecciona Valores origen para configurar la dependencia',
	'LBL_ERR_CYCLIC_DEPENDENCY' => 'Esta dependencia no esta permitida ya que produce una dependencia cíclica',
	'LBL_SELECTED_VALUES' => 'Valores Seleccionados',
	'LBL_CONFIGURE_DEPENDENCY_HELP_1' => 'Solo se muestran valores asignados (salvo la primera vez)',
	'LBL_CONFIGURE_DEPENDENCY_HELP_2' => "Si quieres ver o cambiar la asignación de los otros valores de la lista origen, <br/>
                                          puedes seleccionar los valores pulsando el botón <b>'Selecciona Valores Origen'</b> en el lateral derecho",
	'LBL_CONFIGURE_DEPENDENCY_HELP_3' => 'Valores seleccionados del campo destino, se muestran como',
	'LBL_ADD_BUTTON' => 'Añadir Elemento',
	'LBL_EDIT_BUTTON' => 'Renombrar Elemento',
	'LBL_DELETE_BUTTON' => 'Eliminar Elemento',
	'NTC_DELETE_CONFIRMATION'=>'¿Seguro que quieres eliminar esta dependencia?',
);
?>
